# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: delta_enclave_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='delta_enclave_api.proto',
  package='delta_enclave_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x64\x65lta_enclave_api.proto\x12\x11\x64\x65lta_enclave_api\"m\n\x07Request\x12\x16\n\x0c\x61vatoRequest\x18\x01 \x01(\x0cH\x00\x12?\n\x10\x65xtensionMessage\x18\x02 \x01(\x0b\x32#.delta_enclave_api.ExtensionMessageH\x00\x42\t\n\x07request\"1\n\x10\x45xtensionMessage\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07payload\x18\x02 \x02(\x0c\"T\n\x08Response\x12\x1c\n\x12successfulResponse\x18\x01 \x01(\x0cH\x00\x12\x1e\n\x14unsuccessfulResponse\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"o\n\x0f\x44\x61taNoncePubkey\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05nonce\x18\x02 \x02(\x0c\x12\x0e\n\x06pubkey\x18\x03 \x02(\x0c\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.delta_enclave_api.Authentication\"5\n\x0e\x41uthentication\x12#\n\x03pki\x18\x01 \x02(\x0b\x32\x16.delta_enclave_api.Pki\":\n\x03Pki\x12\x11\n\tcertChain\x18\x01 \x02(\x0c\x12\x11\n\tsignature\x18\x02 \x02(\x0c\x12\r\n\x05idMac\x18\x03 \x02(\x0c\"(\n\tDataNonce\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05nonce\x18\x02 \x02(\x0c\"j\n\x16SealedEncryptedMessage\x12\x36\n\x10\x65ncryptedMessage\x18\x01 \x02(\x0b\x32\x1c.delta_enclave_api.DataNonce\x12\x18\n\x10sealingKeyParams\x18\x02 \x02(\x0c\"W\n\x10\x45ncryptionHeader\x12/\n\x08\x63hilyKey\x18\x01 \x01(\x0b\x32\x1b.delta_enclave_api.ChilyKeyH\x00\x42\x12\n\x10\x65ncryptionHeader\"2\n\x08\x43hilyKey\x12\r\n\x05keyId\x18\x01 \x02(\x0c\x12\x17\n\x0f\x65ncryptionNonce\x18\x02 \x02(\x0c\"\x93\x01\n\x0fIntegrityHeader\x12\x33\n\nbodySha256\x18\x01 \x01(\x0b\x32\x1d.delta_enclave_api.BodySha256H\x00\x12\x37\n\x0cresultSha256\x18\x02 \x01(\x0b\x32\x1f.delta_enclave_api.ResultSha256H\x00\x42\x12\n\x10integrity_header\"\x0c\n\nBodySha256\")\n\x0cResultSha256\x12\x19\n\x11\x63omputationSha256\x18\x01 \x02(\x0c\" \n\rVersionHeader\x12\x0f\n\x07version\x18\x01 \x02(\x03\"=\n\x0b\x43hunkHeader\x12\x14\n\x0c\x65xtraEntropy\x18\x01 \x02(\x0c\x12\x18\n\x10\x66ormatIdentifier\x18\x02 \x02(\t'
)




_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='delta_enclave_api.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatoRequest', full_name='delta_enclave_api.Request.avatoRequest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensionMessage', full_name='delta_enclave_api.Request.extensionMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='delta_enclave_api.Request.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=46,
  serialized_end=155,
)


_EXTENSIONMESSAGE = _descriptor.Descriptor(
  name='ExtensionMessage',
  full_name='delta_enclave_api.ExtensionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='delta_enclave_api.ExtensionMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='delta_enclave_api.ExtensionMessage.payload', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=206,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='delta_enclave_api.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='successfulResponse', full_name='delta_enclave_api.Response.successfulResponse', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsuccessfulResponse', full_name='delta_enclave_api.Response.unsuccessfulResponse', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='delta_enclave_api.Response.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=208,
  serialized_end=292,
)


_DATANONCEPUBKEY = _descriptor.Descriptor(
  name='DataNoncePubkey',
  full_name='delta_enclave_api.DataNoncePubkey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='delta_enclave_api.DataNoncePubkey.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='delta_enclave_api.DataNoncePubkey.nonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='delta_enclave_api.DataNoncePubkey.pubkey', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='delta_enclave_api.DataNoncePubkey.auth', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=405,
)


_AUTHENTICATION = _descriptor.Descriptor(
  name='Authentication',
  full_name='delta_enclave_api.Authentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pki', full_name='delta_enclave_api.Authentication.pki', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=460,
)


_PKI = _descriptor.Descriptor(
  name='Pki',
  full_name='delta_enclave_api.Pki',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certChain', full_name='delta_enclave_api.Pki.certChain', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='delta_enclave_api.Pki.signature', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idMac', full_name='delta_enclave_api.Pki.idMac', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=520,
)


_DATANONCE = _descriptor.Descriptor(
  name='DataNonce',
  full_name='delta_enclave_api.DataNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='delta_enclave_api.DataNonce.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='delta_enclave_api.DataNonce.nonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=562,
)


_SEALEDENCRYPTEDMESSAGE = _descriptor.Descriptor(
  name='SealedEncryptedMessage',
  full_name='delta_enclave_api.SealedEncryptedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encryptedMessage', full_name='delta_enclave_api.SealedEncryptedMessage.encryptedMessage', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sealingKeyParams', full_name='delta_enclave_api.SealedEncryptedMessage.sealingKeyParams', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=670,
)


_ENCRYPTIONHEADER = _descriptor.Descriptor(
  name='EncryptionHeader',
  full_name='delta_enclave_api.EncryptionHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chilyKey', full_name='delta_enclave_api.EncryptionHeader.chilyKey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='encryptionHeader', full_name='delta_enclave_api.EncryptionHeader.encryptionHeader',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=672,
  serialized_end=759,
)


_CHILYKEY = _descriptor.Descriptor(
  name='ChilyKey',
  full_name='delta_enclave_api.ChilyKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyId', full_name='delta_enclave_api.ChilyKey.keyId', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryptionNonce', full_name='delta_enclave_api.ChilyKey.encryptionNonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=811,
)


_INTEGRITYHEADER = _descriptor.Descriptor(
  name='IntegrityHeader',
  full_name='delta_enclave_api.IntegrityHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bodySha256', full_name='delta_enclave_api.IntegrityHeader.bodySha256', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resultSha256', full_name='delta_enclave_api.IntegrityHeader.resultSha256', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='integrity_header', full_name='delta_enclave_api.IntegrityHeader.integrity_header',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=814,
  serialized_end=961,
)


_BODYSHA256 = _descriptor.Descriptor(
  name='BodySha256',
  full_name='delta_enclave_api.BodySha256',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=975,
)


_RESULTSHA256 = _descriptor.Descriptor(
  name='ResultSha256',
  full_name='delta_enclave_api.ResultSha256',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='computationSha256', full_name='delta_enclave_api.ResultSha256.computationSha256', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1018,
)


_VERSIONHEADER = _descriptor.Descriptor(
  name='VersionHeader',
  full_name='delta_enclave_api.VersionHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='delta_enclave_api.VersionHeader.version', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1052,
)


_CHUNKHEADER = _descriptor.Descriptor(
  name='ChunkHeader',
  full_name='delta_enclave_api.ChunkHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extraEntropy', full_name='delta_enclave_api.ChunkHeader.extraEntropy', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatIdentifier', full_name='delta_enclave_api.ChunkHeader.formatIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1115,
)

_REQUEST.fields_by_name['extensionMessage'].message_type = _EXTENSIONMESSAGE
_REQUEST.oneofs_by_name['request'].fields.append(
  _REQUEST.fields_by_name['avatoRequest'])
_REQUEST.fields_by_name['avatoRequest'].containing_oneof = _REQUEST.oneofs_by_name['request']
_REQUEST.oneofs_by_name['request'].fields.append(
  _REQUEST.fields_by_name['extensionMessage'])
_REQUEST.fields_by_name['extensionMessage'].containing_oneof = _REQUEST.oneofs_by_name['request']
_RESPONSE.oneofs_by_name['response'].fields.append(
  _RESPONSE.fields_by_name['successfulResponse'])
_RESPONSE.fields_by_name['successfulResponse'].containing_oneof = _RESPONSE.oneofs_by_name['response']
_RESPONSE.oneofs_by_name['response'].fields.append(
  _RESPONSE.fields_by_name['unsuccessfulResponse'])
_RESPONSE.fields_by_name['unsuccessfulResponse'].containing_oneof = _RESPONSE.oneofs_by_name['response']
_DATANONCEPUBKEY.fields_by_name['auth'].message_type = _AUTHENTICATION
_AUTHENTICATION.fields_by_name['pki'].message_type = _PKI
_SEALEDENCRYPTEDMESSAGE.fields_by_name['encryptedMessage'].message_type = _DATANONCE
_ENCRYPTIONHEADER.fields_by_name['chilyKey'].message_type = _CHILYKEY
_ENCRYPTIONHEADER.oneofs_by_name['encryptionHeader'].fields.append(
  _ENCRYPTIONHEADER.fields_by_name['chilyKey'])
_ENCRYPTIONHEADER.fields_by_name['chilyKey'].containing_oneof = _ENCRYPTIONHEADER.oneofs_by_name['encryptionHeader']
_INTEGRITYHEADER.fields_by_name['bodySha256'].message_type = _BODYSHA256
_INTEGRITYHEADER.fields_by_name['resultSha256'].message_type = _RESULTSHA256
_INTEGRITYHEADER.oneofs_by_name['integrity_header'].fields.append(
  _INTEGRITYHEADER.fields_by_name['bodySha256'])
_INTEGRITYHEADER.fields_by_name['bodySha256'].containing_oneof = _INTEGRITYHEADER.oneofs_by_name['integrity_header']
_INTEGRITYHEADER.oneofs_by_name['integrity_header'].fields.append(
  _INTEGRITYHEADER.fields_by_name['resultSha256'])
_INTEGRITYHEADER.fields_by_name['resultSha256'].containing_oneof = _INTEGRITYHEADER.oneofs_by_name['integrity_header']
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['ExtensionMessage'] = _EXTENSIONMESSAGE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['DataNoncePubkey'] = _DATANONCEPUBKEY
DESCRIPTOR.message_types_by_name['Authentication'] = _AUTHENTICATION
DESCRIPTOR.message_types_by_name['Pki'] = _PKI
DESCRIPTOR.message_types_by_name['DataNonce'] = _DATANONCE
DESCRIPTOR.message_types_by_name['SealedEncryptedMessage'] = _SEALEDENCRYPTEDMESSAGE
DESCRIPTOR.message_types_by_name['EncryptionHeader'] = _ENCRYPTIONHEADER
DESCRIPTOR.message_types_by_name['ChilyKey'] = _CHILYKEY
DESCRIPTOR.message_types_by_name['IntegrityHeader'] = _INTEGRITYHEADER
DESCRIPTOR.message_types_by_name['BodySha256'] = _BODYSHA256
DESCRIPTOR.message_types_by_name['ResultSha256'] = _RESULTSHA256
DESCRIPTOR.message_types_by_name['VersionHeader'] = _VERSIONHEADER
DESCRIPTOR.message_types_by_name['ChunkHeader'] = _CHUNKHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Request)
  })
_sym_db.RegisterMessage(Request)

ExtensionMessage = _reflection.GeneratedProtocolMessageType('ExtensionMessage', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONMESSAGE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ExtensionMessage)
  })
_sym_db.RegisterMessage(ExtensionMessage)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Response)
  })
_sym_db.RegisterMessage(Response)

DataNoncePubkey = _reflection.GeneratedProtocolMessageType('DataNoncePubkey', (_message.Message,), {
  'DESCRIPTOR' : _DATANONCEPUBKEY,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.DataNoncePubkey)
  })
_sym_db.RegisterMessage(DataNoncePubkey)

Authentication = _reflection.GeneratedProtocolMessageType('Authentication', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATION,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Authentication)
  })
_sym_db.RegisterMessage(Authentication)

Pki = _reflection.GeneratedProtocolMessageType('Pki', (_message.Message,), {
  'DESCRIPTOR' : _PKI,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Pki)
  })
_sym_db.RegisterMessage(Pki)

DataNonce = _reflection.GeneratedProtocolMessageType('DataNonce', (_message.Message,), {
  'DESCRIPTOR' : _DATANONCE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.DataNonce)
  })
_sym_db.RegisterMessage(DataNonce)

SealedEncryptedMessage = _reflection.GeneratedProtocolMessageType('SealedEncryptedMessage', (_message.Message,), {
  'DESCRIPTOR' : _SEALEDENCRYPTEDMESSAGE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.SealedEncryptedMessage)
  })
_sym_db.RegisterMessage(SealedEncryptedMessage)

EncryptionHeader = _reflection.GeneratedProtocolMessageType('EncryptionHeader', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.EncryptionHeader)
  })
_sym_db.RegisterMessage(EncryptionHeader)

ChilyKey = _reflection.GeneratedProtocolMessageType('ChilyKey', (_message.Message,), {
  'DESCRIPTOR' : _CHILYKEY,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ChilyKey)
  })
_sym_db.RegisterMessage(ChilyKey)

IntegrityHeader = _reflection.GeneratedProtocolMessageType('IntegrityHeader', (_message.Message,), {
  'DESCRIPTOR' : _INTEGRITYHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.IntegrityHeader)
  })
_sym_db.RegisterMessage(IntegrityHeader)

BodySha256 = _reflection.GeneratedProtocolMessageType('BodySha256', (_message.Message,), {
  'DESCRIPTOR' : _BODYSHA256,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.BodySha256)
  })
_sym_db.RegisterMessage(BodySha256)

ResultSha256 = _reflection.GeneratedProtocolMessageType('ResultSha256', (_message.Message,), {
  'DESCRIPTOR' : _RESULTSHA256,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ResultSha256)
  })
_sym_db.RegisterMessage(ResultSha256)

VersionHeader = _reflection.GeneratedProtocolMessageType('VersionHeader', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.VersionHeader)
  })
_sym_db.RegisterMessage(VersionHeader)

ChunkHeader = _reflection.GeneratedProtocolMessageType('ChunkHeader', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ChunkHeader)
  })
_sym_db.RegisterMessage(ChunkHeader)


# @@protoc_insertion_point(module_scope)
