"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVATOREQUEST_FIELD_NUMBER: builtins.int
    EXTENSIONMESSAGE_FIELD_NUMBER: builtins.int
    avatoRequest: builtins.bytes = ...

    @property
    def extensionMessage(self) -> global___ExtensionMessage: ...

    def __init__(self,
        *,
        avatoRequest : typing.Optional[builtins.bytes] = ...,
        extensionMessage : typing.Optional[global___ExtensionMessage] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"avatoRequest",b"avatoRequest",u"extensionMessage",b"extensionMessage",u"request",b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"avatoRequest",b"avatoRequest",u"extensionMessage",b"extensionMessage",u"request",b"request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"request",b"request"]) -> typing_extensions.Literal["avatoRequest","extensionMessage"]: ...
global___Request = Request

class ExtensionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    payload: builtins.bytes = ...

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        payload : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"name",b"name",u"payload",b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name",u"payload",b"payload"]) -> None: ...
global___ExtensionMessage = ExtensionMessage

class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    UNSUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    successfulResponse: builtins.bytes = ...
    unsuccessfulResponse: typing.Text = ...

    def __init__(self,
        *,
        successfulResponse : typing.Optional[builtins.bytes] = ...,
        unsuccessfulResponse : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response",b"response",u"successfulResponse",b"successfulResponse",u"unsuccessfulResponse",b"unsuccessfulResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response",b"response",u"successfulResponse",b"successfulResponse",u"unsuccessfulResponse",b"unsuccessfulResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"response",b"response"]) -> typing_extensions.Literal["successfulResponse","unsuccessfulResponse"]: ...
global___Response = Response

class DataNoncePubkey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    PUBKEY_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    nonce: builtins.bytes = ...
    pubkey: builtins.bytes = ...

    @property
    def auth(self) -> global___Authentication: ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        nonce : typing.Optional[builtins.bytes] = ...,
        pubkey : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___Authentication] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"data",b"data",u"nonce",b"nonce",u"pubkey",b"pubkey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"data",b"data",u"nonce",b"nonce",u"pubkey",b"pubkey"]) -> None: ...
global___DataNoncePubkey = DataNoncePubkey

class Authentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PKI_FIELD_NUMBER: builtins.int

    @property
    def pki(self) -> global___Pki: ...

    def __init__(self,
        *,
        pki : typing.Optional[global___Pki] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pki",b"pki"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pki",b"pki"]) -> None: ...
global___Authentication = Authentication

class Pki(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CERTCHAIN_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    IDMAC_FIELD_NUMBER: builtins.int
    certChain: builtins.bytes = ...
    signature: builtins.bytes = ...
    idMac: builtins.bytes = ...

    def __init__(self,
        *,
        certChain : typing.Optional[builtins.bytes] = ...,
        signature : typing.Optional[builtins.bytes] = ...,
        idMac : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"certChain",b"certChain",u"idMac",b"idMac",u"signature",b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"certChain",b"certChain",u"idMac",b"idMac",u"signature",b"signature"]) -> None: ...
global___Pki = Pki

class DataNonce(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    nonce: builtins.bytes = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        nonce : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"nonce",b"nonce"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"nonce",b"nonce"]) -> None: ...
global___DataNonce = DataNonce

class SealedEncryptedMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENCRYPTEDMESSAGE_FIELD_NUMBER: builtins.int
    SEALINGKEYPARAMS_FIELD_NUMBER: builtins.int
    sealingKeyParams: builtins.bytes = ...

    @property
    def encryptedMessage(self) -> global___DataNonce: ...

    def __init__(self,
        *,
        encryptedMessage : typing.Optional[global___DataNonce] = ...,
        sealingKeyParams : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptedMessage",b"encryptedMessage",u"sealingKeyParams",b"sealingKeyParams"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptedMessage",b"encryptedMessage",u"sealingKeyParams",b"sealingKeyParams"]) -> None: ...
global___SealedEncryptedMessage = SealedEncryptedMessage

class EncryptionHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHILYKEY_FIELD_NUMBER: builtins.int

    @property
    def chilyKey(self) -> global___ChilyKey: ...

    def __init__(self,
        *,
        chilyKey : typing.Optional[global___ChilyKey] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chilyKey",b"chilyKey",u"encryptionHeader",b"encryptionHeader"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chilyKey",b"chilyKey",u"encryptionHeader",b"encryptionHeader"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"encryptionHeader",b"encryptionHeader"]) -> typing_extensions.Literal["chilyKey"]: ...
global___EncryptionHeader = EncryptionHeader

class ChilyKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYID_FIELD_NUMBER: builtins.int
    ENCRYPTIONNONCE_FIELD_NUMBER: builtins.int
    keyId: builtins.bytes = ...
    encryptionNonce: builtins.bytes = ...

    def __init__(self,
        *,
        keyId : typing.Optional[builtins.bytes] = ...,
        encryptionNonce : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptionNonce",b"encryptionNonce",u"keyId",b"keyId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptionNonce",b"encryptionNonce",u"keyId",b"keyId"]) -> None: ...
global___ChilyKey = ChilyKey

class IntegrityHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BODYSHA256_FIELD_NUMBER: builtins.int
    RESULTSHA256_FIELD_NUMBER: builtins.int

    @property
    def bodySha256(self) -> global___BodySha256: ...

    @property
    def resultSha256(self) -> global___ResultSha256: ...

    def __init__(self,
        *,
        bodySha256 : typing.Optional[global___BodySha256] = ...,
        resultSha256 : typing.Optional[global___ResultSha256] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"bodySha256",b"bodySha256",u"integrity_header",b"integrity_header",u"resultSha256",b"resultSha256"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bodySha256",b"bodySha256",u"integrity_header",b"integrity_header",u"resultSha256",b"resultSha256"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"integrity_header",b"integrity_header"]) -> typing_extensions.Literal["bodySha256","resultSha256"]: ...
global___IntegrityHeader = IntegrityHeader

class BodySha256(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___BodySha256 = BodySha256

class ResultSha256(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPUTATIONSHA256_FIELD_NUMBER: builtins.int
    computationSha256: builtins.bytes = ...

    def __init__(self,
        *,
        computationSha256 : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"computationSha256",b"computationSha256"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computationSha256",b"computationSha256"]) -> None: ...
global___ResultSha256 = ResultSha256

class VersionHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int = ...

    def __init__(self,
        *,
        version : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"version",b"version"]) -> None: ...
global___VersionHeader = VersionHeader

class ChunkHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTRAENTROPY_FIELD_NUMBER: builtins.int
    FORMATIDENTIFIER_FIELD_NUMBER: builtins.int
    extraEntropy: builtins.bytes = ...
    formatIdentifier: typing.Text = ...

    def __init__(self,
        *,
        extraEntropy : typing.Optional[builtins.bytes] = ...,
        formatIdentifier : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"extraEntropy",b"extraEntropy",u"formatIdentifier",b"formatIdentifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"extraEntropy",b"extraEntropy",u"formatIdentifier",b"formatIdentifier"]) -> None: ...
global___ChunkHeader = ChunkHeader
