"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import column_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CsvTableFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COLUMNTYPES_FIELD_NUMBER: builtins.int

    @property
    def columnTypes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[column_type_pb2.ColumnType]: ...

    def __init__(self,
        *,
        columnTypes : typing.Optional[typing.Iterable[column_type_pb2.ColumnType]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnTypes",b"columnTypes"]) -> None: ...
global___CsvTableFormat = CsvTableFormat
