# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: csv_table_format.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import column_type_pb2 as column__type__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='csv_table_format.proto',
  package='csv_table_format',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x63sv_table_format.proto\x12\x10\x63sv_table_format\x1a\x11\x63olumn_type.proto\">\n\x0e\x43svTableFormat\x12,\n\x0b\x63olumnTypes\x18\x01 \x03(\x0b\x32\x17.column_type.ColumnType'
  ,
  dependencies=[column__type__pb2.DESCRIPTOR,])




_CSVTABLEFORMAT = _descriptor.Descriptor(
  name='CsvTableFormat',
  full_name='csv_table_format.CsvTableFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnTypes', full_name='csv_table_format.CsvTableFormat.columnTypes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=125,
)

_CSVTABLEFORMAT.fields_by_name['columnTypes'].message_type = column__type__pb2._COLUMNTYPE
DESCRIPTOR.message_types_by_name['CsvTableFormat'] = _CSVTABLEFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CsvTableFormat = _reflection.GeneratedProtocolMessageType('CsvTableFormat', (_message.Message,), {
  'DESCRIPTOR' : _CSVTABLEFORMAT,
  '__module__' : 'csv_table_format_pb2'
  # @@protoc_insertion_point(class_scope:csv_table_format.CsvTableFormat)
  })
_sym_db.RegisterMessage(CsvTableFormat)


# @@protoc_insertion_point(module_scope)
