"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import column_type_pb2
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___DataRoomStatus = DataRoomStatus
class _DataRoomStatus(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DataRoomStatus.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    Active = DataRoomStatus.V(1)
    Stopped = DataRoomStatus.V(2)
class DataRoomStatus(metaclass=_DataRoomStatus):
    V = typing.NewType('V', builtins.int)
Active = DataRoomStatus.V(1)
Stopped = DataRoomStatus.V(2)

class WaterfrontRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SQLQUERYREQUEST_FIELD_NUMBER: builtins.int
    CREATEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    VALIDATEDATASETREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    JOBSTATUSREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSREQUEST_FIELD_NUMBER: builtins.int
    VALIDATEQUERIESREQUEST_FIELD_NUMBER: builtins.int

    @property
    def sqlQueryRequest(self) -> global___SqlQueryRequest: ...

    @property
    def createDataRoomRequest(self) -> global___CreateDataRoomRequest: ...

    @property
    def publishDatasetToDataRoomRequest(self) -> global___PublishDatasetToDataRoomRequest: ...

    @property
    def retrieveDataRoomRequest(self) -> global___RetrieveDataRoomRequest: ...

    @property
    def validateDatasetRequest(self) -> global___ValidateDatasetRequest: ...

    @property
    def retrieveAuditLogRequest(self) -> global___RetrieveAuditLogRequest: ...

    @property
    def retrieveDataRoomStatusRequest(self) -> global___RetrieveDataRoomStatusRequest: ...

    @property
    def updateDataRoomStatusRequest(self) -> global___UpdateDataRoomStatusRequest: ...

    @property
    def retrievePublishedDatasetRequest(self) -> global___RetrievePublishedDatasetRequest: ...

    @property
    def removePublishedDatasetRequest(self) -> global___RemovePublishedDatasetRequest: ...

    @property
    def jobStatusRequest(self) -> global___JobStatusRequest: ...

    @property
    def getResultsRequest(self) -> global___GetResultsRequest: ...

    @property
    def validateQueriesRequest(self) -> global___ValidateQueriesRequest: ...

    def __init__(self,
        *,
        sqlQueryRequest : typing.Optional[global___SqlQueryRequest] = ...,
        createDataRoomRequest : typing.Optional[global___CreateDataRoomRequest] = ...,
        publishDatasetToDataRoomRequest : typing.Optional[global___PublishDatasetToDataRoomRequest] = ...,
        retrieveDataRoomRequest : typing.Optional[global___RetrieveDataRoomRequest] = ...,
        validateDatasetRequest : typing.Optional[global___ValidateDatasetRequest] = ...,
        retrieveAuditLogRequest : typing.Optional[global___RetrieveAuditLogRequest] = ...,
        retrieveDataRoomStatusRequest : typing.Optional[global___RetrieveDataRoomStatusRequest] = ...,
        updateDataRoomStatusRequest : typing.Optional[global___UpdateDataRoomStatusRequest] = ...,
        retrievePublishedDatasetRequest : typing.Optional[global___RetrievePublishedDatasetRequest] = ...,
        removePublishedDatasetRequest : typing.Optional[global___RemovePublishedDatasetRequest] = ...,
        jobStatusRequest : typing.Optional[global___JobStatusRequest] = ...,
        getResultsRequest : typing.Optional[global___GetResultsRequest] = ...,
        validateQueriesRequest : typing.Optional[global___ValidateQueriesRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createDataRoomRequest",b"createDataRoomRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetRequest",b"retrievePublishedDatasetRequest",u"sqlQueryRequest",b"sqlQueryRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest",u"validateDatasetRequest",b"validateDatasetRequest",u"validateQueriesRequest",b"validateQueriesRequest",u"waterfront_request",b"waterfront_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createDataRoomRequest",b"createDataRoomRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetRequest",b"retrievePublishedDatasetRequest",u"sqlQueryRequest",b"sqlQueryRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest",u"validateDatasetRequest",b"validateDatasetRequest",u"validateQueriesRequest",b"validateQueriesRequest",u"waterfront_request",b"waterfront_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"waterfront_request",b"waterfront_request"]) -> typing_extensions.Literal["sqlQueryRequest","createDataRoomRequest","publishDatasetToDataRoomRequest","retrieveDataRoomRequest","validateDatasetRequest","retrieveAuditLogRequest","retrieveDataRoomStatusRequest","updateDataRoomStatusRequest","retrievePublishedDatasetRequest","removePublishedDatasetRequest","jobStatusRequest","getResultsRequest","validateQueriesRequest"]: ...
global___WaterfrontRequest = WaterfrontRequest

class WaterfrontResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int
    SQLQUERYRESPONSE_FIELD_NUMBER: builtins.int
    CREATEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    VALIDATEDATASETRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    JOBSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    VALIDATEQUERIESRESPONSE_FIELD_NUMBER: builtins.int
    failure: typing.Text = ...

    @property
    def sqlQueryResponse(self) -> global___SqlQueryResponse: ...

    @property
    def createDataRoomResponse(self) -> global___CreateDataRoomResponse: ...

    @property
    def publishDatasetToDataRoomResponse(self) -> global___PublishDatasetToDataRoomResponse: ...

    @property
    def retrieveDataRoomResponse(self) -> global___RetrieveDataRoomResponse: ...

    @property
    def validateDatasetResponse(self) -> global___ValidateDatasetResponse: ...

    @property
    def retrieveAuditLogResponse(self) -> global___RetrieveAuditLogResponse: ...

    @property
    def retrieveDataRoomStatusResponse(self) -> global___RetrieveDataRoomStatusResponse: ...

    @property
    def updateDataRoomStatusResponse(self) -> global___UpdateDataRoomStatusResponse: ...

    @property
    def retrievePublishedDatasetResponse(self) -> global___RetrievePublishedDatasetResponse: ...

    @property
    def removePublishedDatasetResponse(self) -> global___RemovePublishedDatasetResponse: ...

    @property
    def jobStatusResponse(self) -> global___JobStatusResponse: ...

    @property
    def validateQueriesResponse(self) -> global___ValidateQueriesResponse: ...

    def __init__(self,
        *,
        failure : typing.Optional[typing.Text] = ...,
        sqlQueryResponse : typing.Optional[global___SqlQueryResponse] = ...,
        createDataRoomResponse : typing.Optional[global___CreateDataRoomResponse] = ...,
        publishDatasetToDataRoomResponse : typing.Optional[global___PublishDatasetToDataRoomResponse] = ...,
        retrieveDataRoomResponse : typing.Optional[global___RetrieveDataRoomResponse] = ...,
        validateDatasetResponse : typing.Optional[global___ValidateDatasetResponse] = ...,
        retrieveAuditLogResponse : typing.Optional[global___RetrieveAuditLogResponse] = ...,
        retrieveDataRoomStatusResponse : typing.Optional[global___RetrieveDataRoomStatusResponse] = ...,
        updateDataRoomStatusResponse : typing.Optional[global___UpdateDataRoomStatusResponse] = ...,
        retrievePublishedDatasetResponse : typing.Optional[global___RetrievePublishedDatasetResponse] = ...,
        removePublishedDatasetResponse : typing.Optional[global___RemovePublishedDatasetResponse] = ...,
        jobStatusResponse : typing.Optional[global___JobStatusResponse] = ...,
        validateQueriesResponse : typing.Optional[global___ValidateQueriesResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createDataRoomResponse",b"createDataRoomResponse",u"failure",b"failure",u"jobStatusResponse",b"jobStatusResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetResponse",b"retrievePublishedDatasetResponse",u"sqlQueryResponse",b"sqlQueryResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse",u"validateDatasetResponse",b"validateDatasetResponse",u"validateQueriesResponse",b"validateQueriesResponse",u"waterfront_response",b"waterfront_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createDataRoomResponse",b"createDataRoomResponse",u"failure",b"failure",u"jobStatusResponse",b"jobStatusResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetResponse",b"retrievePublishedDatasetResponse",u"sqlQueryResponse",b"sqlQueryResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse",u"validateDatasetResponse",b"validateDatasetResponse",u"validateQueriesResponse",b"validateQueriesResponse",u"waterfront_response",b"waterfront_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"waterfront_response",b"waterfront_response"]) -> typing_extensions.Literal["failure","sqlQueryResponse","createDataRoomResponse","publishDatasetToDataRoomResponse","retrieveDataRoomResponse","validateDatasetResponse","retrieveAuditLogResponse","retrieveDataRoomStatusResponse","updateDataRoomStatusResponse","retrievePublishedDatasetResponse","removePublishedDatasetResponse","jobStatusResponse","validateQueriesResponse"]: ...
global___WaterfrontResponse = WaterfrontResponse

class AuthenticationData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROLE_FIELD_NUMBER: builtins.int
    PASSWORDSHA256_FIELD_NUMBER: builtins.int
    role: typing.Text = ...
    passwordSha256: typing.Text = ...

    def __init__(self,
        *,
        role : typing.Optional[typing.Text] = ...,
        passwordSha256 : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"passwordSha256",b"passwordSha256",u"role",b"role"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"passwordSha256",b"passwordSha256",u"role",b"role"]) -> None: ...
global___AuthenticationData = AuthenticationData

class CreateDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___CreateDataRoomRequest = CreateDataRoomRequest

class CreateDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomHash",b"dataRoomHash",u"dataRoomValidationError",b"dataRoomValidationError"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomHash",b"dataRoomHash",u"dataRoomValidationError",b"dataRoomValidationError"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response"]) -> typing_extensions.Literal["dataRoomHash","dataRoomValidationError"]: ...
global___CreateDataRoomResponse = CreateDataRoomResponse

class DataRoomValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    QUERYINDEX_FIELD_NUMBER: builtins.int
    COLUMNINDEX_FIELD_NUMBER: builtins.int
    TABLEINDEX_FIELD_NUMBER: builtins.int
    ROLEINDEX_FIELD_NUMBER: builtins.int
    PERMISSIONINDEX_FIELD_NUMBER: builtins.int
    CONSTRAINTINDEX_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    queryIndex: builtins.int = ...
    columnIndex: builtins.int = ...
    tableIndex: builtins.int = ...
    roleIndex: builtins.int = ...
    permissionIndex: builtins.int = ...
    constraintIndex: builtins.int = ...

    def __init__(self,
        *,
        message : typing.Optional[typing.Text] = ...,
        queryIndex : typing.Optional[builtins.int] = ...,
        columnIndex : typing.Optional[builtins.int] = ...,
        tableIndex : typing.Optional[builtins.int] = ...,
        roleIndex : typing.Optional[builtins.int] = ...,
        permissionIndex : typing.Optional[builtins.int] = ...,
        constraintIndex : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"columnIndex",b"columnIndex",u"constraintIndex",b"constraintIndex",u"message",b"message",u"permissionIndex",b"permissionIndex",u"queryIndex",b"queryIndex",u"roleIndex",b"roleIndex",u"tableIndex",b"tableIndex"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnIndex",b"columnIndex",u"constraintIndex",b"constraintIndex",u"message",b"message",u"permissionIndex",b"permissionIndex",u"queryIndex",b"queryIndex",u"roleIndex",b"roleIndex",u"tableIndex",b"tableIndex"]) -> None: ...
global___DataRoomValidationError = DataRoomValidationError

class PublishDatasetToDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMTABLENAME_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...
    dataRoomHash: builtins.bytes = ...
    dataRoomTableName: typing.Text = ...

    @property
    def encryptionKey(self) -> global___EncryptionKey: ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomTableName : typing.Optional[typing.Text] = ...,
        encryptionKey : typing.Optional[global___EncryptionKey] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> None: ...
global___PublishDatasetToDataRoomRequest = PublishDatasetToDataRoomRequest

class PublishDatasetToDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___PublishDatasetToDataRoomResponse = PublishDatasetToDataRoomResponse

class ValidateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...

    @property
    def encryptionKey(self) -> global___EncryptionKey: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        encryptionKey : typing.Optional[global___EncryptionKey] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> None: ...
global___ValidateDatasetRequest = ValidateDatasetRequest

class ValidateDatasetFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    ROW_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    row: builtins.int = ...

    def __init__(self,
        *,
        message : typing.Optional[typing.Text] = ...,
        row : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"message",b"message",u"row",b"row"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"message",b"message",u"row",b"row"]) -> None: ...
global___ValidateDatasetFailure = ValidateDatasetFailure

class ValidateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int

    @property
    def failure(self) -> global___ValidateDatasetFailure: ...

    def __init__(self,
        *,
        failure : typing.Optional[global___ValidateDatasetFailure] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"failure",b"failure"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"failure",b"failure"]) -> None: ...
global___ValidateDatasetResponse = ValidateDatasetResponse

class SqlQueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYNAME_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    queryName: typing.Text = ...
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        queryName : typing.Optional[typing.Text] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"queryName",b"queryName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"queryName",b"queryName"]) -> None: ...
global___SqlQueryRequest = SqlQueryRequest

class SqlQueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INPROGRESS_FIELD_NUMBER: builtins.int
    FINISHED_FIELD_NUMBER: builtins.int

    @property
    def inProgress(self) -> global___SqlQueryInProgress: ...

    @property
    def finished(self) -> global___SqlQueryFinished: ...

    def __init__(self,
        *,
        inProgress : typing.Optional[global___SqlQueryInProgress] = ...,
        finished : typing.Optional[global___SqlQueryFinished] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"finished",b"finished",u"inProgress",b"inProgress",u"sql_query_response",b"sql_query_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"finished",b"finished",u"inProgress",b"inProgress",u"sql_query_response",b"sql_query_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sql_query_response",b"sql_query_response"]) -> typing_extensions.Literal["inProgress","finished"]: ...
global___SqlQueryResponse = SqlQueryResponse

class SqlQueryInProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___SqlQueryInProgress = SqlQueryInProgress

class SqlQueryFinished(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    header: google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text] = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        header : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"header",b"header"]) -> None: ...
global___SqlQueryFinished = SqlQueryFinished

class JobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> None: ...
global___JobStatusRequest = JobStatusRequest

class JobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETED_FIELD_NUMBER: builtins.int
    completed: builtins.bool = ...

    def __init__(self,
        *,
        completed : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"completed",b"completed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completed",b"completed"]) -> None: ...
global___JobStatusResponse = JobStatusResponse

class GetResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> None: ...
global___GetResultsRequest = GetResultsRequest

class RetrieveDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveDataRoomRequest = RetrieveDataRoomRequest

class RetrieveDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___RetrieveDataRoomResponse = RetrieveDataRoomResponse

class RetrieveAuditLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveAuditLogRequest = RetrieveAuditLogRequest

class RetrieveAuditLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___RetrieveAuditLogResponse = RetrieveAuditLogResponse

class RetrieveDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveDataRoomStatusRequest = RetrieveDataRoomStatusRequest

class RetrieveDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    status: global___DataRoomStatus.V = ...

    def __init__(self,
        *,
        status : typing.Optional[global___DataRoomStatus.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___RetrieveDataRoomStatusResponse = RetrieveDataRoomStatusResponse

class UpdateDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...
    status: global___DataRoomStatus.V = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        status : typing.Optional[global___DataRoomStatus.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"status",b"status"]) -> None: ...
global___UpdateDataRoomStatusRequest = UpdateDataRoomStatusRequest

class UpdateDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___UpdateDataRoomStatusResponse = UpdateDataRoomStatusResponse

class RetrievePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrievePublishedDatasetRequest = RetrievePublishedDatasetRequest

class PublishedDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATASET_HASH_FIELD_NUMBER: builtins.int
    table: typing.Text = ...
    user: typing.Text = ...
    timestamp: builtins.int = ...
    dataset_hash: builtins.bytes = ...

    def __init__(self,
        *,
        table : typing.Optional[typing.Text] = ...,
        user : typing.Optional[typing.Text] = ...,
        timestamp : typing.Optional[builtins.int] = ...,
        dataset_hash : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataset_hash",b"dataset_hash",u"table",b"table",u"timestamp",b"timestamp",u"user",b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataset_hash",b"dataset_hash",u"table",b"table",u"timestamp",b"timestamp",u"user",b"user"]) -> None: ...
global___PublishedDataset = PublishedDataset

class RetrievePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLISHEDDATASETS_FIELD_NUMBER: builtins.int

    @property
    def publishedDatasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublishedDataset]: ...

    def __init__(self,
        *,
        publishedDatasets : typing.Optional[typing.Iterable[global___PublishedDataset]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"publishedDatasets",b"publishedDatasets"]) -> None: ...
global___RetrievePublishedDatasetResponse = RetrievePublishedDatasetResponse

class RemovePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMTABLENAME_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...
    dataRoomHash: builtins.bytes = ...
    dataRoomTableName: typing.Text = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomTableName : typing.Optional[typing.Text] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"manifestHash",b"manifestHash"]) -> None: ...
global___RemovePublishedDatasetRequest = RemovePublishedDatasetRequest

class RemovePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RemovePublishedDatasetResponse = RemovePublishedDatasetResponse

class ValidateQueriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___ValidateQueriesRequest = ValidateQueriesRequest

class QuerySchemas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLESCHEMAS_FIELD_NUMBER: builtins.int

    @property
    def tableSchemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableSchema]: ...

    def __init__(self,
        *,
        tableSchemas : typing.Optional[typing.Iterable[global___TableSchema]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tableSchemas",b"tableSchemas"]) -> None: ...
global___QuerySchemas = QuerySchemas

class ValidateQueriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYSCHEMAS_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int

    @property
    def querySchemas(self) -> global___QuerySchemas: ...

    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...

    def __init__(self,
        *,
        querySchemas : typing.Optional[global___QuerySchemas] = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoomValidationError",b"dataRoomValidationError",u"querySchemas",b"querySchemas",u"validate_queries_response",b"validate_queries_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomValidationError",b"dataRoomValidationError",u"querySchemas",b"querySchemas",u"validate_queries_response",b"validate_queries_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"validate_queries_response",b"validate_queries_response"]) -> typing_extensions.Literal["querySchemas","dataRoomValidationError"]: ...
global___ValidateQueriesResponse = ValidateQueriesResponse

class EncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MATERIAL_FIELD_NUMBER: builtins.int
    SALT_FIELD_NUMBER: builtins.int
    material: builtins.bytes = ...
    salt: builtins.bytes = ...

    def __init__(self,
        *,
        material : typing.Optional[builtins.bytes] = ...,
        salt : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"material",b"material",u"salt",b"salt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"material",b"material",u"salt",b"salt"]) -> None: ...
global___EncryptionKey = EncryptionKey

class TableSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAMEDCOLUMNS_FIELD_NUMBER: builtins.int

    @property
    def namedColumns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedColumn]: ...

    def __init__(self,
        *,
        namedColumns : typing.Optional[typing.Iterable[global___NamedColumn]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"namedColumns",b"namedColumns"]) -> None: ...
global___TableSchema = TableSchema

class NamedColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    COLUMNTYPE_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    @property
    def columnType(self) -> column_type_pb2.ColumnType: ...

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        columnType : typing.Optional[column_type_pb2.ColumnType] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"columnType",b"columnType",u"name",b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnType",b"columnType",u"name",b"name"]) -> None: ...
global___NamedColumn = NamedColumn

class DatasetManifest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DIGESTHASH_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    digestHash: builtins.bytes = ...

    @property
    def schema(self) -> global___TableSchema: ...

    def __init__(self,
        *,
        digestHash : typing.Optional[builtins.bytes] = ...,
        schema : typing.Optional[global___TableSchema] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"digestHash",b"digestHash",u"schema",b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"digestHash",b"digestHash",u"schema",b"schema"]) -> None: ...
global___DatasetManifest = DatasetManifest
